@@ -2,7 +2,6 @@
 #define _PROFILECHANGERWIDGET_H_
 
 #include <QMainWindow>
-#include <QDBusInterface>
 #include <qmaemo5homescreenadaptor.h>
 #include <QErrorMessage>
 #include "settingsdialog.h"
@@ -29,6 +28,7 @@ public slots:
 
 private:
     Ui::ProfileChangerWidget *ui;
+    bool showNextProfile;
 
 private:
     QString getProfileName();
