@@ -155,9 +155,12 @@ void SettingsDialog::showQuestion(QString info)
         "org.freedesktop.Notifications", // message name (w/o method)
         "SystemNoteDialog" // method
     );
-    msg << info;
-    msg << 0;
-    msg << "Ok";
+    QList<QVariant> args;
+    args.append(info);
+    args.append(static_cast<quint32>(0));
+    args.append("ok");
+
+    msg.setArguments(args);
     msg = QDBusConnection::sessionBus().call(msg);
 
 }
